@@ -77,16 +77,20 @@ class DatabaseClient():
             required = ("dbname", "host", "user", "password", "port")
             defaults = {"port": 5432}
             self.config = validateConfig(required, config, defaults=defaults)
-            self.client = psycopg2.connect(
-                dbname=self.config["dbname"],
-                user=self.config["user"],
-                host=self.config["host"],
-                password=self.config["password"],
-                port=self.config["port"]
-            )
+            self.client = None
+            self.connect()
             self.client_type = "instance"
             self.commit = self.client.commit
 
+    def connect(self):
+        self.client = psycopg2.connect(
+            dbname=self.config["dbname"],
+            user=self.config["user"],
+            host=self.config["host"],
+            password=self.config["password"],
+            port=self.config["port"]
+        )
+
     def close(self):
         """Close the database connection for client_type of "instance"
 
@@ -169,11 +173,15 @@ class DatabaseClient():
         parameters = {} if "parameters" not in kwargs else kwargs["parameters"]
         cursor_type = DictCursor if pretty else None
         c = self.client.cursor(cursor_factory=cursor_type)
-        c.execute(
-            sql,
-            parameters
-        )
-        if commit: self.client.commit()
+        try:
+            c.execute(
+                sql,
+                parameters
+            )
+            if commit: self.client.commit()
+        except Exception as e:
+            if commit: self.client.commit()
+            raise e
         try:
             if pretty: r = [dict(x) for x in c.fetchall()]
             else: r = [list(x) for x in c.fetchall()]
